# Generated by roxygen2: do not edit by hand

export(GVS)
export(GVS_citations)
export(GVS_collaborators)
export(GVS_data_dictionary)
export(GVS_metadata)
export(GVS_sources)
export(GVS_version)
import(httr)
importFrom(httr,GET)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
