#' Example GVS data
#'
#' A sample dataset showing the proper formatting of GVS inputs.
#'
#' @format A data.frame with 27 observations of 2 variables:
#' \describe{
#'   \item{Latitude}{Latitude, in decimal degrees}
#'   \item{Longitude}{Longitude, in decimal degrees}
#'   ...
#' }
#' @source \url{https://biendata.org}
"gvs_testfile"
