% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_internet.R
\name{check_internet}
\alias{check_internet}
\title{Check whether the internet is on}
\usage{
check_internet()
}
\value{
TRUE if internet connection is detected, FALSE otherwise.
}
\description{
Check for internet
}
\keyword{internal}
